"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.openExternal = exports.isInView = exports.pointInRectangle = void 0;
const electron_1 = require("electron");
const path = require("path");
const URL = require("url");
const getLogger_1 = require("../logging/getLogger");
const showDialog_1 = require("../lib/showDialog");
const config_1 = require("../settings/config");
const locale = require("../locale/locale");
const logger = getLogger_1.getLogger(path.basename(__filename));
exports.pointInRectangle = (point, rectangle) => {
    const [x, y] = point;
    const xInRange = x >= rectangle.x && x <= rectangle.x + rectangle.width;
    const yInRange = y >= rectangle.y && y <= rectangle.y + rectangle.height;
    return xInRange && yInRange;
};
exports.isInView = (win) => {
    const windowBounds = win.getBounds();
    const nearestWorkArea = electron_1.screen.getDisplayMatching(windowBounds).workArea;
    const upperLeftVisible = exports.pointInRectangle([windowBounds.x, windowBounds.y], nearestWorkArea);
    const lowerRightVisible = exports.pointInRectangle([windowBounds.x + windowBounds.width, windowBounds.y + windowBounds.height], nearestWorkArea);
    return upperLeftVisible || lowerRightVisible;
};
exports.openExternal = (url, httpsOnly = false) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const urlProtocol = URL.parse(url).protocol || '';
        const allowedProtocols = ['https:'];
        if (!httpsOnly) {
            allowedProtocols.push('ftp:', 'http:', 'mailto:', `${config_1.config.customProtocolName}:`);
        }
        if (!allowedProtocols.includes(urlProtocol)) {
            logger.warn(`Prevented opening external URL "${url}".`);
            showDialog_1.showWarningDialog(locale.getText('urlBlockedPromptText'));
            return;
        }
        yield electron_1.shell.openExternal(url);
    }
    catch (error) {
        logger.error(error);
    }
});
//# sourceMappingURL=WindowUtil.js.map